@@ -6,9 +6,8 @@ use deno_core::serde::Deserialize;
 use deno_core::serde::Deserializer;
 use deno_core::serde::Serialize;
 use deno_core::serde::Serializer;
-use deno_core::ModuleSpecifier;
+use deno_graph::ModuleGraphError;
 use regex::Regex;
-use std::collections::HashMap;
 use std::error::Error;
 use std::fmt;
 
@@ -30,7 +29,6 @@ const UNSTABLE_DENO_PROPS: &[&str] = &[
   "Metrics",
   "OpMetrics",
   "RecordType",
-  "ResolveDnsOptions",
   "SRVRecord",
   "SetRawOptions",
   "SignalStream",
@@ -54,7 +52,6 @@ const UNSTABLE_DENO_PROPS: &[&str] = &[
   "dlopen",
   "osRelease",
   "ppid",
-  "resolveDns",
   "setRaw",
   "shutdown",
   "Signal",
@@ -355,20 +352,17 @@ impl Diagnostics {
     Diagnostics(diagnostics)
   }
 
-  pub fn extend_graph_errors(
-    &mut self,
-    errors: HashMap<ModuleSpecifier, String>,
-  ) {
-    self.0.extend(errors.into_iter().map(|(s, e)| Diagnostic {
+  pub fn extend_graph_errors(&mut self, errors: Vec<ModuleGraphError>) {
+    self.0.extend(errors.into_iter().map(|err| Diagnostic {
       category: DiagnosticCategory::Error,
       code: 900001,
       start: None,
       end: None,
-      message_text: Some(e),
+      message_text: Some(err.to_string()),
       message_chain: None,
       source: None,
       source_line: None,
-      file_name: Some(s.to_string()),
+      file_name: Some(err.specifier().to_string()),
       related_information: None,
     }));
   }
