@@ -6,7 +6,10 @@ Deno.test("broadcastchannel worker", async () => {
   const intercom = new BroadcastChannel("intercom");
   let count = 0;
 
-  const url = new URL("../workers/broadcast_channel.ts", import.meta.url);
+  const url = new URL(
+    "../testdata/workers/broadcast_channel.ts",
+    import.meta.url,
+  );
   const worker = new Worker(url.href, { type: "module", name: "worker" });
   worker.onmessage = () => intercom.postMessage(++count);
 
