@@ -2,7 +2,7 @@
 import { assert, assertEquals, unitTest } from "./test_util.ts";
 
 // deno-lint-ignore no-explicit-any
-function testFirstArgument(arg1: any[], expectedSize: number): void {
+function testFirstArgument(arg1: any[], expectedSize: number) {
   const file = new File(arg1, "name");
   assert(file instanceof File);
   assertEquals(file.name, "name");
@@ -10,47 +10,47 @@ function testFirstArgument(arg1: any[], expectedSize: number): void {
   assertEquals(file.type, "");
 }
 
-unitTest(function fileEmptyFileBits(): void {
+unitTest(function fileEmptyFileBits() {
   testFirstArgument([], 0);
 });
 
-unitTest(function fileStringFileBits(): void {
+unitTest(function fileStringFileBits() {
   testFirstArgument(["bits"], 4);
 });
 
-unitTest(function fileUnicodeStringFileBits(): void {
+unitTest(function fileUnicodeStringFileBits() {
   testFirstArgument(["𝓽𝓮𝔁𝓽"], 16);
 });
 
-unitTest(function fileStringObjectFileBits(): void {
+unitTest(function fileStringObjectFileBits() {
   testFirstArgument([new String("string object")], 13);
 });
 
-unitTest(function fileEmptyBlobFileBits(): void {
+unitTest(function fileEmptyBlobFileBits() {
   testFirstArgument([new Blob()], 0);
 });
 
-unitTest(function fileBlobFileBits(): void {
+unitTest(function fileBlobFileBits() {
   testFirstArgument([new Blob(["bits"])], 4);
 });
 
-unitTest(function fileEmptyFileFileBits(): void {
+unitTest(function fileEmptyFileFileBits() {
   testFirstArgument([new File([], "world.txt")], 0);
 });
 
-unitTest(function fileFileFileBits(): void {
+unitTest(function fileFileFileBits() {
   testFirstArgument([new File(["bits"], "world.txt")], 4);
 });
 
-unitTest(function fileArrayBufferFileBits(): void {
+unitTest(function fileArrayBufferFileBits() {
   testFirstArgument([new ArrayBuffer(8)], 8);
 });
 
-unitTest(function fileTypedArrayFileBits(): void {
+unitTest(function fileTypedArrayFileBits() {
   testFirstArgument([new Uint8Array([0x50, 0x41, 0x53, 0x53])], 4);
 });
 
-unitTest(function fileVariousFileBits(): void {
+unitTest(function fileVariousFileBits() {
   testFirstArgument(
     [
       "bits",
@@ -64,45 +64,45 @@ unitTest(function fileVariousFileBits(): void {
   );
 });
 
-unitTest(function fileNumberInFileBits(): void {
+unitTest(function fileNumberInFileBits() {
   testFirstArgument([12], 2);
 });
 
-unitTest(function fileArrayInFileBits(): void {
+unitTest(function fileArrayInFileBits() {
   testFirstArgument([[1, 2, 3]], 5);
 });
 
-unitTest(function fileObjectInFileBits(): void {
+unitTest(function fileObjectInFileBits() {
   // "[object Object]"
   testFirstArgument([{}], 15);
 });
 
 // deno-lint-ignore no-explicit-any
-function testSecondArgument(arg2: any, expectedFileName: string): void {
+function testSecondArgument(arg2: any, expectedFileName: string) {
   const file = new File(["bits"], arg2);
   assert(file instanceof File);
   assertEquals(file.name, expectedFileName);
 }
 
-unitTest(function fileUsingFileName(): void {
+unitTest(function fileUsingFileName() {
   testSecondArgument("dummy", "dummy");
 });
 
-unitTest(function fileUsingNullFileName(): void {
+unitTest(function fileUsingNullFileName() {
   testSecondArgument(null, "null");
 });
 
-unitTest(function fileUsingNumberFileName(): void {
+unitTest(function fileUsingNumberFileName() {
   testSecondArgument(1, "1");
 });
 
-unitTest(function fileUsingEmptyStringFileName(): void {
+unitTest(function fileUsingEmptyStringFileName() {
   testSecondArgument("", "");
 });
 
 unitTest(
-  { perms: { read: true, write: true } },
-  function fileTruncateSyncSuccess(): void {
+  { permissions: { read: true, write: true } },
+  function fileTruncateSyncSuccess() {
     const filename = Deno.makeTempDirSync() + "/test_fileTruncateSync.txt";
     const file = Deno.openSync(filename, {
       create: true,
@@ -123,8 +123,8 @@ unitTest(
 );
 
 unitTest(
-  { perms: { read: true, write: true } },
-  async function fileTruncateSuccess(): Promise<void> {
+  { permissions: { read: true, write: true } },
+  async function fileTruncateSuccess() {
     const filename = Deno.makeTempDirSync() + "/test_fileTruncate.txt";
     const file = await Deno.open(filename, {
       create: true,
@@ -144,7 +144,7 @@ unitTest(
   },
 );
 
-unitTest({ perms: { read: true } }, function fileStatSyncSuccess(): void {
+unitTest({ permissions: { read: true } }, function fileStatSyncSuccess() {
   const file = Deno.openSync("README.md");
   const fileInfo = file.statSync();
   assert(fileInfo.isFile);
@@ -159,9 +159,7 @@ unitTest({ perms: { read: true } }, function fileStatSyncSuccess(): void {
   file.close();
 });
 
-unitTest({ perms: { read: true } }, async function fileStatSuccess(): Promise<
-  void
-> {
+unitTest({ permissions: { read: true } }, async function fileStatSuccess() {
   const file = await Deno.open("README.md");
   const fileInfo = await file.stat();
   assert(fileInfo.isFile);
