@@ -1,4 +1,9 @@
-import { assertStringIncludes, unitTest, unreachable } from "./test_util.ts";
+import {
+  assert,
+  assertStringIncludes,
+  unitTest,
+  unreachable,
+} from "./test_util.ts";
 
 unitTest(async function sendAsyncStackTrace() {
   const buf = new Uint8Array(10);
@@ -11,6 +16,10 @@ unitTest(async function sendAsyncStackTrace() {
     console.log(s);
     assertStringIncludes(s, "opcall_test.ts");
     assertStringIncludes(s, "read");
+    assert(
+      !s.includes("deno:core"),
+      "opcall stack traces should NOT include deno:core internals such as unwrapOpResult",
+    );
   }
 });
 
@@ -21,7 +30,7 @@ declare global {
   }
 }
 
-unitTest(async function opsAsyncBadResource(): Promise<void> {
+unitTest(async function opsAsyncBadResource() {
   try {
     const nonExistingRid = 9999;
     await Deno.core.opAsync(
@@ -36,7 +45,7 @@ unitTest(async function opsAsyncBadResource(): Promise<void> {
   }
 });
 
-unitTest(function opsSyncBadResource(): void {
+unitTest(function opsSyncBadResource() {
   try {
     const nonExistingRid = 9999;
     Deno.core.opSync("op_read_sync", nonExistingRid, new Uint8Array(0));
